==> haskell-invariant-0.5.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.1
id: invariant-0.5.1-EvDaR2lfTpy6ITeQ7Xp1Qe
key: invariant-0.5.1-EvDaR2lfTpy6ITeQ7Xp1Qe
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: 4e7b4af46fc59b910c7ff81e2d2c56c6
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/invariant-0.5.1
hs-libraries: HSinvariant-0.5.1-EvDaR2lfTpy6ITeQ7Xp1Qe
depends:
    array-0.5.2.0 base-4.11.1.0 bifunctors-5.5.3-Brx4ioiidy0E4oOA1rufI1
    comonad-5.0.4-DMINZ0aMd8oFIhjlIqJSEs containers-0.5.11.0
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA ghc-prim-0.5.2.0
    profunctors-5.3-B9XGNPj9eNIFYnD8OF7KYD
    StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-Brx4ioiidy0E4oOA1rufI1=12f884716dc473d98235a4d0de188cc4
             comonad-5.0.4-DMINZ0aMd8oFIhjlIqJSEs=fef355d343d551e29f05ec96a9889e51
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             profunctors-5.3-B9XGNPj9eNIFYnD8OF7KYD=7d21ce46d9fc7d5c2a62dc0d959da342
             StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb=b777c54e6eb83c2075ba969a9e5dd06d
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.5.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.1
id: invariant-0.5.1-Z8c7gt2pgLID5UaMxJxh0
key: invariant-0.5.1-Z8c7gt2pgLID5UaMxJxh0
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: 0ccc8719832baa344d762862b3e70a43
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/invariant-0.5.1
hs-libraries: HSinvariant-0.5.1-Z8c7gt2pgLID5UaMxJxh0
depends:
    array-0.5.2.0 base-4.11.1.0 bifunctors-5.5.3-B2s1kTwvG5P67s9a0vFF69
    comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH containers-0.5.11.0
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA ghc-prim-0.5.2.0
    profunctors-5.3-FeDuHDGI4bOCxClca48Fbi
    StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-B2s1kTwvG5P67s9a0vFF69=8adb81346affd1af6f03238f8ca73e7f
             comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH=73ea1c02e78d1366c378f0246c151a40
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             profunctors-5.3-FeDuHDGI4bOCxClca48Fbi=b6c03e8ca3a4111776a405a0612a8055
             StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb=b777c54e6eb83c2075ba969a9e5dd06d
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
